@@ -68,9 +68,8 @@ def renew(task, coro, fargs, *args, **kwargs):
             raise e
     else:
         try:
-            loop = task.get_loop()
-            loop.stop()
-            return False
+            result = task.result()
+            return result
         except Exception as e:
             raise e
 
@@ -196,6 +195,8 @@ class TaskLoop:
                 result = task.result()
                 result_args, result_kwargs = result
                 loop = asyncio.get_event_loop()
+                if exception := result_kwargs.get("exception"):
+                    raise exception
                 if self.control == "STOP" or result_kwargs.get('stop'):
                     return "STOPPED"
                 elif self.control in {"START", "CONTINUE"}:
@@ -214,21 +215,24 @@ class TaskLoop:
                                             name=self.name)
                     task.add_done_callback(
                         functools.partial(self.renew, task, pause, fargs))
+            except asyncio.IncompleteReadError as incomplete_read:
+                print("IncompleteReadError {incomplete_read}")
+                print("Result incomplete: {incomplete_read.partial}")
+                raise incomplete_read
             except asyncio.InvalidStateError as ie:
                 print("Invalid State Error", ie, "Coro", coro, "args", args,
                       "kargs", kwargs)
                 raise ie
             except Exception as e:
                 log = result_kwargs.get('log')
-                msg = f"""TaskLoop. TResultado  cancelled {task.cancelled()},
+                msg = f"""TaskLoop. Result cancelled {task.cancelled()},
                     task {task},
                     coro {coro},
                     fargs {fargs}"""
                 if task.done():
                     msg_done = f"TaskLoop, exception, Task done {task.result()}"
-                    print(msg_done)
                     if log:
-                        log.exception(msg)
+                        log.exception(msg_done)
                 print(msg)
                 if log:
                     log.exception(msg)
@@ -236,8 +240,7 @@ class TaskLoop:
                 raise e
         else:
             try:
-                loop = task.get_loop()
-                loop.stop()
-                return False
+                result = task.result()
+                return result
             except Exception as e:
                 raise e
